summaryrefslogtreecommitdiff
path: root/src/modules/m_helpop.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_helpop.cpp')
-rw-r--r--src/modules/m_helpop.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_helpop.cpp b/src/modules/m_helpop.cpp
index a7bd4a8c5..bbc7ae3ac 100644
--- a/src/modules/m_helpop.cpp
+++ b/src/modules/m_helpop.cpp
@@ -21,7 +21,7 @@
*/
/* $ModDesc: Provides the /HELPOP command, works like UnrealIRCd's helpop */
#include "inspircd.h"
@@ -188,7 +188,7 @@ class ModuleHelpop : public Module
Version GetVersion()
{
- return Version("Provides the /HELPOP command, works like UnrealIRCd's helpop", VF_VENDOR);
+ return Version("Provides the /HELPOP command for useful information", VF_VENDOR);
}
};
@@ -21,7 +21,7 @@
*/
-/* $ModDesc: Provides the /HELPOP command, works like UnrealIRCd's helpop */
+/* $ModDesc: Provides the /HELPOP command for useful information */
#include "inspircd.h"